==> drools-core-5.2.0.Final-sources.jar: org/drools/common/ScheduledAgendaItem.java <==
/*
 * Copyright 2005 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.common;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import org.drools.core.util.LinkedListNode;
import org.drools.reteoo.LeftTuple;
import org.drools.reteoo.RuleTerminalNode;
import org.drools.rule.GroupElement;
import org.drools.rule.Rule;
import org.drools.spi.Activation;
import org.drools.spi.PropagationContext;
import org.drools.spi.Tuple;
import org.drools.time.JobHandle;

public class ScheduledAgendaItem extends AgendaItem
    implements
    Activation,
    Externalizable,
    LinkedListNode {

    private static final long        serialVersionUID = 510l;

    private LinkedListNode           previous;

    private LinkedListNode           next;

//
    private InternalAgenda     agenda;
    
    private JobHandle jobHandle;

    public ScheduledAgendaItem(final long activationNumber,
                               final LeftTuple tuple,
                               final InternalAgenda agenda,
                               final PropagationContext context,
                               final RuleTerminalNode rtn) {
        super(activationNumber, tuple, 0, context, rtn );
        this.agenda = agenda;
    }

    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
        super.readExternal( in );
        
        previous    = (LinkedListNode)in.readObject();
        next    = (LinkedListNode)in.readObject();
        agenda    = (InternalAgenda)in.readObject();
    }

    public void writeExternal(ObjectOutput out) throws IOException {
        super.writeExternal( out );
        out.writeObject(previous);
        out.writeObject(agenda);
    }
    public LinkedListNode getNext() {
        return this.next;
    }

    public void setNext(final LinkedListNode next) {
        this.next = next;
    }

    public LinkedListNode getPrevious() {
        return this.previous;
    }

    public void setPrevious(final LinkedListNode previous) {
        this.previous = previous;
    }

    public void remove() {
        this.agenda.removeScheduleItem( this );
    }
    
    public JobHandle getJobHandle() {
        return this.jobHandle;
    }

    public void setJobHandle(JobHandle jobHandle) {
        this.jobHandle = jobHandle;
    }
    
    public String toString() {
        return "[ScheduledActivation rule=" + getRule().getName() + ", tuple=" + getTuple() + "]";
    }
}

==> drools-core-5.6.0.Final-sources.jar: org/drools/common/ScheduledAgendaItem.java <==
/*
 * Copyright 2005 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.common;

import org.drools.core.util.Entry;
import org.drools.core.util.LinkedListNode;
import org.drools.reteoo.LeftTuple;
import org.drools.reteoo.RuleTerminalNode;
import org.drools.spi.Activation;
import org.drools.spi.PropagationContext;
import org.drools.time.JobHandle;
import org.drools.time.Trigger;
import org.drools.time.impl.CronTrigger;
import org.drools.time.impl.DefaultJobHandle;

import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.util.concurrent.atomic.AtomicBoolean;

public class ScheduledAgendaItem extends AgendaItem
    implements
    Activation,
    Externalizable,
    LinkedListNode<ScheduledAgendaItem> {

    private static final long        serialVersionUID = 510l;

    private ScheduledAgendaItem      previous;

    private ScheduledAgendaItem      next;

//
    private InternalAgenda           agenda;

    private AtomicBoolean            enqueued;
    
    private JobHandle jobHandle;

    public ScheduledAgendaItem(final long activationNumber,
                               final LeftTuple tuple,
                               final InternalAgenda agenda,
                               final PropagationContext context,
                               final RuleTerminalNode rtn) {
        super(activationNumber, tuple, 0, context, rtn );
        this.agenda = agenda;
        this.enqueued = new AtomicBoolean( false );
    }

    public void readExternal(ObjectInput in) throws IOException, ClassNotFoundException {
        super.readExternal( in );        
        agenda   = (InternalAgenda)in.readObject();
        enqueued = new AtomicBoolean( in.readBoolean() );
    }

    public void writeExternal(ObjectOutput out) throws IOException {
        super.writeExternal( out );
        out.writeObject( agenda );
        out.writeBoolean( enqueued.get() );
    }
    public ScheduledAgendaItem getNext() {
        return this.next;
    }

    public void setNext(final ScheduledAgendaItem next) {
        this.next = next;
    }    

    public void setNext(Entry next) {
        this.next = (ScheduledAgendaItem) next;
    }    

    public ScheduledAgendaItem getPrevious() {
        return this.previous;
    }

    public void setPrevious(final ScheduledAgendaItem previous) {
        this.previous = previous;
    }

    public void remove() {
        this.agenda.removeScheduleItem( this );
    }
    
    public JobHandle getJobHandle() {
        return this.jobHandle;
    }

    public void setJobHandle(JobHandle jobHandle) {
        this.jobHandle = jobHandle;
    }
    
    public String toString() {
        return "[ScheduledActivation rule=" + getRule().getName() + ", tuple=" + getTuple() + "]";
    }

    public boolean isEnqueued() {
        return enqueued.get();
    }

    public AtomicBoolean getEnqueued() {
        return enqueued;
    }

    public void setEnqueued( boolean enqueued ) {
        this.enqueued.getAndSet( enqueued );
    }

    public boolean isPendingReactivation() {
        DefaultJobHandle timeHandle = (DefaultJobHandle) getJobHandle();
        Trigger trig = timeHandle.getTimerJobInstance().getTrigger();
        return trig.hasNextFireTime() != null && trig instanceof CronTrigger;
    }
}
